ERbRadiusScheme class

Inheritance
Annotations

Constructors

ERbRadiusScheme({required Radius tiny, required Radius small, required Radius medium, required Radius large, required Radius huge})
const
ERbRadiusScheme.fallback()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
huge Radius
final
large Radius
final
medium Radius
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
small Radius
final
tiny Radius
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({Radius? tiny, Radius? small, Radius? medium, Radius? large, Radius? huge}) ERbRadiusScheme
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ERbRadiusScheme? other, double t) ThemeExtension<ERbRadiusScheme>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override